<?php

$options = get_option( 'growmatik_consents', array() );

?>
<div class="wrap">
	<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
	<div class="growmatik-card">
		<h3 class="growmatik-card-title">
			<span>
				<?php esc_html_e( 'Status: ', 'growmatik' ); ?>
				<?php if ( \Growmatik\Admin\Health_Check::is_in_progress() ) : ?>
					<span id="wait-for-health-check-done" class="growmatik-loader growmatik-inline-block"></span>
				<?php elseif ( \Growmatik\Admin\Health_Check::has_errors() ) : ?>
					<em class="growmatik-text-danger"><?php esc_html_e( 'Error', 'growmatik' ); ?></em>
				<?php elseif ( \Growmatik\Admin\Integration::is_paused() ) : ?>
					<em class="growmatik-text-warning"><?php esc_html_e( 'Paused', 'growmatik' ); ?></em>
				<?php else : ?>
					<em class="growmatik-text-success"><?php esc_html_e( 'Connected', 'growmatik' ); ?></em>
				<?php endif; ?>
			</span>
			<?php if ( \Growmatik\Admin\Health_Check::site_exists() ) : ?>
				<a class="button button-secondary" target="_blank" href="<?php echo esc_url( sprintf( '%s/sites/%s/reports', GROWMATIK_APP_URL, get_option( 'growmatik_site_id' ) ) ); ?>">
					<?php esc_html_e( 'View Dashboard', 'growmatik' ); ?>
				</a>
			<?php else : ?>
				<button class="button button-secondary" title="<?php esc_attr_e( 'Site has been removed.', 'growmatik' ); ?>" disabled>
					<?php esc_html_e( 'View Dashboard', 'growmatik' ); ?>
				</button>
			<?php endif; ?>
		</h3>
		<h4><?php esc_html_e( 'Integration details:', 'growmatik' ); ?></h4>
		<p>
			<strong><?php esc_html_e( 'Growmatik Account:', 'growmatik' ); ?></strong>
			<?php echo esc_html( get_option( 'growmatik_user_email', __( '[Unknown]', 'growmatik' ) ) ); ?>
		</p>
		<p>
			<strong><?php esc_html_e( 'Site URL:', 'growmatik' ); ?></strong>
			<?php /* translators: %s is a URL. */ ?>
			<?php echo esc_html( get_option( 'growmatik_site_url', sprintf( __( '%s (Reported by WordPress)', 'growmatik' ), get_site_url() ) ) ); ?>
		</p>
		<p>
			<strong><?php esc_html_e( 'Site ID:', 'growmatik' ); ?></strong>
			<?php echo esc_html( get_option( 'growmatik_site_id', __( '[Unknown]', 'growmatik' ) ) ); ?>
		</p>
		<?php if ( \Growmatik\Admin\Integration::is_paused() ) : ?>
			<p class="growmatik-card-row">
				<span><?php esc_html_e( 'Resume the integration to continue executing rules.', 'growmatik' ); ?></span>
				<button class="button button-secondary growmatik-resume-integration"><?php esc_html_e( 'Resume', 'growmatik' ); ?></button>
			</p>
		<?php else : ?>
			<p class="growmatik-card-row">
				<?php /* translators: %s is a Learn More link. */ ?>
				<span><?php esc_html_e( 'Temporarily pause the integration. Rules will not be executed. Analytics and data gathering will keep running.', 'growmatik' ); ?></span>
				<button class="button button-secondary growmatik-pause-integration"><?php esc_html_e( 'Pause', 'growmatik' ); ?></button>
			</p>
		<?php endif; ?>
		<p class="growmatik-card-row">
			<?php /* translators: %s is a Learn More link. */ ?>
			<span><?php esc_html_e( 'Stop synchronizing your site and rule execution.', 'growmatik' ); ?></span>
			<button class="button growmatik-button-danger growmatik-disconnect-confirm"><?php esc_html_e( 'Remove Integration', 'growmatik' ); ?></button>
		</p>
		<div class="growmatik-dialog" id="growmatik-disconnect-dialog">
			<div class="growmatik-dialog-header">
				<h3 class="growmatik-dialog-title"><?php esc_html_e( 'Disconnect Growmatik.ai?', 'growmatik' ); ?></h3>
			</div>
			<div class="growmatik-dialog-content">
				<p><?php esc_html_e( 'Are you sure you want to disconnect your site?', 'growmatik' ); ?></p>
				<p><?php esc_html_e( 'Data synchronization will be stopped and the rules will stop executing. You can pause the synchronization instead.', 'growmatik' ); ?></p>
			</div>
			<div class="growmatik-dialog-footer">
				<button class="button button-primary growmatik-remove-integration"><?php esc_html_e( 'Remove Integration', 'growmatik' ); ?></button>
				<button class="button button-secondary growmatik-dialog-close"><?php esc_html_e( 'Cancel', 'growmatik' ); ?></button>
			</div>
		</div>
	</div>
	<div class="growmatik-card">
		<h3 class="growmatik-card-title">
			<span><?php esc_html_e( 'Settings', 'growmatik' ); ?></span>
		</h3>
		<p>
			<h4>
				<span>
					<?php esc_html_e( 'Marketing Email Consent', 'growmatik' ); ?>
				</span>
				<span
					class="growmatik-help-icon"
					title="<?php esc_attr_e( 'If you want to send marketing emails to your users, you should collect their consent when they sign up to your website. In this section you can define which forms to show the consent checkbox and its content.', 'growmatik' ); ?>"
				>
					<span class="dashicons dashicons-editor-help"></span>
				</span>
			</h4>
			<div class="growmatik-setting-field">
				<input type="checkbox" id="growmatik-consent-signup" name="growmatik_consent_signup" <?php echo $options['signup'] ? 'checked' : ''; ?> >
				<label for="growmatik-consent-signup">
				<?php esc_html_e( 'Show in WordPress native signup form', 'growmatik' ); ?>
				</label>
			</div>
			<div class="growmatik-setting-field">
				<input type="checkbox" id="growmatik-consent-wc-signup" name="growmatik_consent_wc_signup" <?php echo $options['wc_signup'] ? 'checked' : ''; ?>>
				<label for="growmatik-consent-wc-signup">
					<?php esc_html_e( 'Show in WooCommerce signup form', 'growmatik' ); ?>
				</label>
			</div>
			<div class="growmatik-setting-field">
				<input type="checkbox" id="growmatik-consent-wc-checkout" name="growmatik_consent_wc_checkout" <?php echo $options['wc_checkout'] ? 'checked' : ''; ?>>
				<label for="growmatik-consent-wc-checkout">
				<?php esc_html_e( 'Show in WooCommerce Checkout page', 'growmatik' ); ?>
				</label>
			</div>
			</p>
		<p>
			<h4>
				<?php esc_html_e( 'Marketing Email Consent Statement', 'growmatik' ); ?>
			</h4>
			<?php
			$consent_text = __( 'I\'d like to subscribe to {{sitename}} newsletter to get product updates & news, weekly digest, and more.', 'growmatik' );

			if ( $options['consent_text'] ) {
				$consent_text = $options['consent_text'];
			}
			?>
			<textarea name="growmatik_consent_statement" id="growmatik_consent_statement" cols="70" rows="3"><?php echo esc_html( $consent_text ); ?></textarea>
			<div class="growmatik-hint">
				<small>
					<?php esc_html_e( 'You can use {{sitename}} and it will be replaced by your sitename automatically.', 'growmatik' ); ?>
				</small>
			</div>
		</p>
		<p>
			<div class="growmatik-dialog-footer">
				<?php wp_nonce_field( 'growmatik_save_settings', 'growmatik_settings_nonce' ); ?>
				<button id="growmatik-save-settings" class="button button-primary"><?php esc_html_e( 'Save', 'growmatik' ); ?></button>
			</div>
		</p>
	</div>
</div>

<?php
