<?php

namespace Growmatik\Front;

use Growmatik;
use Growmatik\Admin\Integration;

class Init {

	public function __construct() {
		add_action( 'wp_enqueue_scripts', array( $this, 'add_growmatik_if_then' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'add_inline_scripts' ), 9 );
	}

	public function add_growmatik_if_then() {
		wp_enqueue_script( 'growmatik-if-then' );
	}

	public function add_inline_scripts() {
		global $wp;

		$site_id      = get_option( 'growmatik_site_id' );
		$user_type    = Growmatik\get_user_type();
		$current_user = ( 'guest' === $user_type ) ? null : wp_get_current_user();
		$orders       = new Growmatik\Controller\User_Order_Controller();
		$cart_items   = Growmatik\get_cart_items();
		$has_cart     = count( $cart_items ) > 0;
		$last_order   = $orders->get_last_order();

		$growmatik = array(
			'growmatikApi' => esc_url( GROWMATIK_API_URL ),
			'integration'  => Integration::is_paused() ? 'paused' : 'active',
			'siteId'       => esc_html( $site_id ),
			'env'          => esc_html( GROWMATIK_APP_ENV ),
			'currentTime'  => esc_html( date( 'Y-m-d H:i:s' ) ),
			'site'         => array(
				'id'  => esc_html( $site_id ),
				'url' => esc_url( rtrim( site_url(), '/' ) ),
			),
			'page'         => array(
				'wpUrl'    => esc_url( '/' . $wp->request ),
				'postType' => esc_html( get_post_type() ),
				'postId'   => get_the_ID(),
				'isSingle' => ( is_single() || is_page() ) ? true : false,
			),
			'user'         => array(
				'type'               => esc_html( $user_type ),
				'id'                 => $current_user ? esc_html( $current_user->ID ) : '',
				'username'           => $current_user ? esc_html( $current_user->user_login ) : '',
				'firstName'          => $current_user ? esc_html( $current_user->first_name ) : '',
				'lastName'           => $current_user ? esc_html( $current_user->last_name ) : '',
				'registered'         => $current_user ? esc_html( $current_user->user_registered ) : '',
				'email'              => $current_user ? esc_html( $current_user->user_email ) : '',
				'products'           => apply_filters( 'growmatik_user_purchased_product_ids', $orders->list_of_purchased_product_ids() ),
				'noOfOrders'         => $current_user ? esc_html( $orders->get_user_order_count( $current_user->ID ) ) : 0,
				'noOfPurchasedItems' => apply_filters( 'growmatik_user_total_purchased_items', $orders->get_total_purchased_items() ),
				'cartItems'          => $cart_items,
				'hasCart'            => $has_cart,
				'lastOrder'          => $last_order,
			),
		);

		wp_localize_script( 'growmatik-if-then', '_growmatik', $growmatik );
	}

}
